@@ -278,7 +278,7 @@ class Distributive(object):
     @staticmethod
     def clear_empty_directories(dn):
         dn = path.dirname(dn)
-        while path.exists(dn) and isEmpty(dn):
+        while dn and path.exists(dn) and isEmpty(dn) and not isMount(dn):
             os.rmdir(dn)
             dn = path.dirname(dn)
 
